@@ -15,7 +15,7 @@
 # You should have received a copy of the GNU General Public License along
 # with PFT.  If not, see <http://www.gnu.org/licenses/>.
 #
-package PFT::Header v0.5.4;
+package PFT::Header v1.0.0;
 
 =encoding utf8
 
@@ -218,7 +218,14 @@ sub load {
 The following functions are not associated with an instance. Call them as
 C<PFT::Header::function(...)>
 
-=over 1 slugify
+=over
+
+=item slugify
+
+Given a string, construct a I<slug>, that is a simplified version of such
+string.
+
+(TODO: better describe it, also w.r.t. Unicode)
 
 =cut
 
@@ -233,9 +240,9 @@ sub slugify {
     lc $out
 };
 
-=head2 Properties
+=back
 
-=over 1
+=head2 Properties
 
     $hdr->title
     $hdr->author
@@ -246,7 +253,7 @@ sub slugify {
     $hdr->slug
     $hdr->tags_slug
 
-=cut
+=over
 
 =item title
 
@@ -316,7 +323,7 @@ sub tags_slug {
     map slugify($_) => @{shift->tags || []}
 }
 
-=over
+=back
 
 =head2 Methods
 
@@ -324,6 +331,8 @@ sub tags_slug {
 
 =item set_date
 
+Setter for date. The parameter must be a PFT::Date object.
+
 =cut
 
 sub set_date {
