@@ -15,7 +15,7 @@
 # You should have received a copy of the GNU General Public License along
 # with PFT.  If not, see <http://www.gnu.org/licenses/>.
 #
-package PFT::Map v0.5.4;
+package PFT::Map v1.0.0;
 
 =encoding utf8
 
@@ -48,9 +48,10 @@ use File::Spec;
 use Encode::Locale qw/$ENCODING_LOCALE/;
 
 use PFT::Map::Node;
-use PFT::Map::Resolver qw/resolve/;
+use PFT::Map::Index;
 use PFT::Text;
 use PFT::Header;
+use PFT::Date;
 
 sub new {
     my $cls = shift;
@@ -77,10 +78,16 @@ sub new {
 sub _resolve {
     # Resolving items in $self->{toresolve}. They are inserted in _mknod.
     my $self = shift;
+    my $index = $self->index;
 
     for my $node (@{$self->{toresolve}}) {
         for my $s ($node->symbols) {
-            my $resolved = eval { resolve($self, $node, $s) };
+            my $resolved = eval {
+                my @rs = $index->resolve($node, $s);
+                croak "Multiple results: @rs\n" if @rs > 1;
+                $rs[0]
+            };
+
             if (defined $resolved) {
                 if (!ref($resolved) || $resolved->isa('PFT::Map::Node')) {
                     # scalar or other node
@@ -101,50 +108,13 @@ sub _resolve {
     delete $self->{toresolve}
 };
 
-sub _content_id {
-    # Given a PFT::Content::Base (or any subclass) object, returns a
-    # string uniquely identifying it across the site. E.g.:
-    #
-    #     my $id = $map->_content_id($content);
-    #     my $id = $map->_content_id($virtual_page, $hdr);
-    #     my $id = $map->_content_id(undef, $hdr);
-    #
-    # Form 1: for any content
-
-    my($self, $cntnt, $hdr) = @_;
-
-    unless (defined $cntnt) {
-        confess 'No content, no header?' unless defined $hdr;
-        $cntnt = $self->{tree}->entry($hdr);
-    }
-
-    ref($cntnt) =~ /PFT::Content::(Page|Blog|Picture|Attachment|Tag|Month)/
-        or confess 'Unsupported in content to id: ' . ref($cntnt);
-
-    if ($1 eq 'Page') {
-        'p:' . ($hdr || $cntnt->header)->slug
-    } elsif ($1 eq 'Tag') {
-        't:' . ($hdr || $cntnt->header)->slug
-    } elsif ($1 eq 'Blog') {
-        my $hdr = ($hdr || $cntnt->header);
-        'b:' . $hdr->date->repr('') . ':' . $hdr->slug
-    } elsif ($1 eq 'Month') {
-        my $hdr = ($hdr || $cntnt->header);
-        'm:' . $hdr->date->repr('')
-    } elsif ($1 eq 'Picture') {
-        'i:' . join '/', $cntnt->relpath # No need for portability
-    } elsif ($1 eq 'Attachment') {
-        'a:' . join '/', $cntnt->relpath # Ditto
-    } else { die };
-}
-
 sub _mknod {
     my $self = shift;
     my($cntnt, $hdr) = @_;
 
     my $node = PFT::Map::Node->new(
         $self->{next} ++,
-        (my $id = $self->_content_id(@_)),
+        (my $id = $self->index->content_id(@_)),
         @_,
     );
 
@@ -230,7 +200,28 @@ List of the nodes
 
 =cut
 
-sub nodes { values %{shift->{idx}} }
+sub nodes {
+    my $self = shift;
+    if (@_) {
+        @{$self->{idx}}{@_}
+    } else {
+        values %{$self->{idx}}
+    }
+}
+
+=item ids
+
+List of the mnemonic ids.
+
+    map $m->id_to_node($_), $m->ids
+
+is equivalent to
+
+    $m->nodes
+
+=cut
+
+sub ids { keys %{shift->{idx}} }
 
 =item tree
 
@@ -269,8 +260,21 @@ List of tag nodes
 
 sub tags { shift->_grep_content('PFT::Content::Tag') }
 
+=item index
+
+The PFT::Map::Index object associated to this map.
+
+It handles the unique identifiers of content items and can be used to
+query the map.
+
+=cut
+
+sub index { PFT::Map::Index->new(shift) }
+
 =item dump
 
+# TODO: move forward this description, as method
+
 Dump of the nodes in a easy-to-display form, that is a list of
 dictionaries.
 
@@ -337,48 +341,81 @@ associated node, or undef if such node does not exist.
 
 sub node_of {
     my $self = shift;
-    my $id = $self->_content_id(@_);
-
+    my $id = $self->index->content_id(@_);
     exists $self->{idx}{$id} ? $self->{idx}{$id} : undef
 }
 
-=item recent_blog
+=item id_to_node
 
-The I<N> most recent blog nodes.
+Given a unique mnemonic id (as in C<PFT::Content::Node::id>) returns the
+associated node, or C<undef> if there is no such node.
 
-The number I<N> is given as parameter, and defaults to 1. The method
-returns up to I<N> nodes, ordered by date, from most to least recent.
+=cut
+
+sub id_to_node {
+    my $idx = shift->{idx};
+    my $id = shift;
+    exists $idx->{$id} ? $idx->{$id} : undef
+}
+
+=item blog_recent
+
+Getter for the most recent blog nodes.
+
+The number I<N> can be provided as parameter, and defaults to 1 if not
+provided.
+
+In list context returns the I<N> + 1 most recent blog nodes, ordered by date,
+from most to least recent. Less than I<N> nodes will be returned if I<N>
+is greater than the number of available entries.
+
+In scalar context returns the I<N>-th to last entry. For I<N> equal to
+zero the most recent entry is returned.
 
 =cut
 
 sub _recent {
     my($self, $key, $n) = @_;
 
-    $n = 1 unless defined $n;
-    confess "Requires N > 0, got $n" if $n < 1;
+    $n = 0 unless defined $n;
+    confess "Requires N > 0, got $n" if $n < 0;
 
-    my @out;
     my $cursor = $self->{$key};
-    while ($n -- && defined $cursor) {
-        push @out, $cursor;
-        $cursor = $cursor->prev;
-    }
 
-    @out;
+    wantarray ? do {
+        my @out = $cursor;
+        while ($n -- && defined $cursor) {
+            $cursor = $cursor->prev;
+            push @out, $cursor;
+        }
+        @out;
+    } : do {
+        while ($n -- && defined $cursor) {
+            $cursor = $cursor->prev;
+        }
+        $cursor;
+    }
 }
 
-sub recent_blog { shift->_recent('last', shift) }
+sub blog_recent { shift->_recent('last', shift) }
 
-=item recent_months
+=item months_recent
 
-The I<N> most recent months node.
+Getter for the most recent month nodes.
 
-The number I<N> is given as parameter, and defaults to 1. The method
-returns up to I<N> nodes, ordered by date, from most to least recent.
+The number I<N> can be provided as parameter, and defaults to 1 if not
+provided.
+
+In list context returns the I<N> + 1 most recent month nodes, ordered by date,
+from most to least recent. Less than I<N> nodes will be returned if I<N>
+is greater than the number of available entries.
+
+In scalar context returns the I<N>-th to last entry. For I<N> equal to
+zero the most recent entry is returned.
 
 =cut
 
-sub recent_months { shift->_recent('last_month', shift) }
+sub months_recent { shift->_recent('last_month', shift) }
 
 =back
 
